@@ -236,7 +236,7 @@ class Colormap
     @@instance.send meth, *a
   end
   # Performance shortcut
-  def self.color_for *a; @@instance.color_for *a; end
+  def self.color_for(*a); @@instance.color_for(*a); end
 end
 
 end
