@@ -425,7 +425,7 @@ EOS
 
     ## gmail style "is" operator
     subs = subs.gsub(/\b(is|has):(\S+)\b/) do
-      field, label = $1, $2
+      _field, label = $1, $2
       case label
       when "read"
         "-label:unread"
@@ -649,7 +649,7 @@ EOS
   end
 
   def synchronize &b
-    @index_mutex.synchronize &b
+    @index_mutex.synchronize(&b)
   end
 
   def run_query xapian_query, offset, limit, checkatleast=0
