@@ -102,7 +102,7 @@ class Source
   end
 
   def synchronize &block
-    @poll_lock.synchronize &block
+    @poll_lock.synchronize(&block)
   end
 
   def try_lock
@@ -153,7 +153,7 @@ class Source
       next unless Rfc2047.is_encoded? v
       header[k] = begin
         Rfc2047.decode_to $encoding, v
-      rescue Errno::EINVAL, Iconv::InvalidEncoding, Iconv::IllegalSequence => e
+      rescue Errno::EINVAL, Iconv::InvalidEncoding, Iconv::IllegalSequence
         #debug "warning: error decoding RFC 2047 header (#{e.class.name}): #{e.message}"
         v
       end
@@ -169,6 +169,12 @@ protected
   def Source.expand_filesystem_uri uri
     uri.gsub "~", File.expand_path("~")
   end
+
+  def Source.encode_path_for_uri path
+    path.gsub(Regexp.new("[#{Regexp.quote(URI_ENCODE_CHARS)}]")) { |c|
+      c.each_byte.map { |x| sprintf("%%%02X", x) }.join
+    }
+  end
 end
 
 ## if you have a @labels instance variable, include this
