@@ -4,6 +4,7 @@ require 'thread'
 require 'lockfile'
 require 'mime/types'
 require 'pathname'
+require 'rmail'
 require 'set'
 require 'enumerator'
 require 'benchmark'
@@ -11,7 +12,7 @@ require 'unicode'
 require 'unicode/display_width'
 require 'fileutils'
 
-class Lockfile
+module ExtendedLockfile
   def gen_lock_id
     Hash[
          'host' => "#{ Socket.gethostname }",
@@ -37,6 +38,7 @@ class Lockfile
 
   def touch_yourself; touch path end
 end
+Lockfile.send :prepend, ExtendedLockfile
 
 class File
   # platform safe file.link which attempts a copy if hard-linking fails
@@ -106,7 +108,7 @@ module RMail
     end
   end
 
-  class Serialize
+  module CustomizedSerialize
     ## Don't add MIME-Version headers on serialization. Sup sometimes want's to serialize
     ## message parts where these headers are not needed and messing with the message on
     ## serialization breaks gpg signatures. The commented section shows the original RMail
@@ -118,48 +120,7 @@ module RMail
       # end
     end
   end
-
-  class Header
-
-    # Convert to ASCII before trying to match with regexp
-    class Field
-
-      class << self
-        def parse(field)
-          field = field.dup.to_s
-          field = field.fix_encoding!.ascii
-          if field =~ EXTRACT_FIELD_NAME_RE
-            [ $1, $'.chomp ]
-          else
-            [ "", Field.value_strip(field) ]
-          end
-        end
-      end
-    end
-
-    ## Be more cautious about invalid content-type headers
-    ## the original RMail code calls
-    ## value.strip.split(/\s*;\s*/)[0].downcase
-    ## without checking if split returned an element
-
-    # This returns the full content type of this message converted to
-    # lower case.
-    #
-    # If there is no content type header, returns the passed block is
-    # executed and its return value is returned.  If no block is passed,
-    # the value of the +default+ argument is returned.
-    def content_type(default = nil)
-      if value = self['content-type'] and ct = value.strip.split(/\s*;\s*/)[0]
-        return ct.downcase
-      else
-        if block_given?
-          yield
-        else
-          default
-        end
-      end
-    end
-  end
+  Serialize.send :prepend, CustomizedSerialize
 end
 
 class Module
@@ -392,8 +353,23 @@ class String
     self
   end
 
+  ## Decodes UTF-7 and returns the resulting decoded string as UTF-8.
+  ##
+  ## Ruby doesn't supply a UTF-7 encoding natively. There is
+  ## Net::IMAP::decode_utf7 which only handles the IMAP "modified UTF-7"
+  ## encoding. This implementation is inspired by that one but handles
+  ## standard UTF-7 shift characters and not the IMAP-specific variation.
+  def decode_utf7
+    gsub(/\+([^-]+)?-/) {
+      if $1
+        ($1 + "===").unpack("m")[0].encode(Encoding::UTF_8, Encoding::UTF_16BE)
+      else
+        "+"
+      end
+    }
+  end
+
   def normalize_whitespace
-    fix_encoding!
     gsub(/\t/, "    ").gsub(/\r/, "")
   end
 
@@ -405,7 +381,7 @@ class String
 
   unless method_defined? :each
     def each &b
-      each_line &b
+      each_line(&b)
     end
   end
 
@@ -507,7 +483,9 @@ module Enumerable
     ret
   end
 
-  def sum; inject(0) { |x, y| x + y }; end
+  if not method_defined? :sum
+    def sum; inject(0) { |x, y| x + y }; end
+  end
 
   def map_to_hash
     ret = {}
@@ -563,7 +541,9 @@ class Array
     inject([]) { |a, e| a + e }
   end
 
-  def to_h; Hash[*flatten]; end
+  if not method_defined? :to_h
+    def to_h; Hash[*flatten_one_level]; end
+  end
   def rest; self[1..-1]; end
 
   def to_boolean_h; Hash[*map { |x| [x, true] }.flatten]; end
